@@ -29,7 +29,7 @@ def test_unary(
     for i in passing:
         assert check(i)
     for i in failing:
-        with raises(AssertionError, match=escape(red(f"{infix} {i}"))):
+        with raises(AssertionError, match=escape(red(f"{infix}{i}"))):
             assert check(i)
 
 
@@ -37,30 +37,36 @@ _test_sentinel = object()
 
 
 @mark.parametrize(
-    "checker, value, infix, passing, failing",
+    "checker, value, template, passing, failing",
     [
-        (Check.lt, 0, "<", [-1, -2, -3], [0, 1, 2]),
-        (Check.le, 0, "<=", [0, -1, -2], [1, 2, 3]),
-        (Check.eq, 0, "==", [0], [1, -1, 2, -2]),
-        (Check.ne, 0, "!=", [1, -1, 2, -2], [0]),
-        (Check.ge, 0, ">=", [0, 1, 2], [-1, -2, -3]),
-        (Check.gt, 0, ">", [1, 2, 3], [0, -1, -2]),
-        (Check.is_, _test_sentinel, "is", [_test_sentinel], [object()]),
-        (Check.contains, 0, "contains", [[0], [0, 1], [0, 1, 2]], [[], [-1], [-2]]),
+        (Check.lt, 0, "< {0}", [-1, -2, -3], [0, 1, 2]),
+        (Check.le, 0, "<= {0}", [0, -1, -2], [1, 2, 3]),
+        (Check.eq, 0, "== {0}", [0], [1, -1, 2, -2]),
+        (Check.ne, 0, "!= {0}", [1, -1, 2, -2], [0]),
+        (Check.ge, 0, ">= {0}", [0, 1, 2], [-1, -2, -3]),
+        (Check.gt, 0, "> {0}", [1, 2, 3], [0, -1, -2]),
+        (Check.is_, _test_sentinel, "is {0}", [_test_sentinel], [object()]),
+        (Check.contains, 0, "{0} in", [[0], [0, 1], [0, 1, 2]], [[], [-1], [-2]]),
     ],
 )
 def test_binary(
     checker: Callable[[Any], Checker],
     value: Any,
-    infix: str,
+    template: str,
     passing: List[Any],
     failing: List[Any],
 ) -> None:
     check = checker(value)
     assert isinstance(check, Checker)
-    assert repr(check) == f"{infix} {value}"
+    exp_repr = template.format(value)
+    assert repr(check) == exp_repr
     for i in passing:
         assert check(i)
     for i in failing:
-        with raises(AssertionError, match=escape(red(f"{i} {infix} {value}"))):
+        with raises(
+            AssertionError,
+            match=escape(
+                red(f"{exp_repr} {i}" if template.startswith("{0}") else f"{i} {exp_repr}"),
+            ),
+        ):
             assert check(i)
